@@ -86,6 +86,27 @@ sub new {
     return $self;
 }
 
+=item parse_element()
+
+ Type    : Factory method
+ Title   : parse_element
+ Usage   : $elt = $dom->parse_element($text)
+ Function: Create a new XML DOM element from XML text
+ Returns : DOM element
+ Args    : An XML String
+
+=cut
+
+sub parse_element {
+    my ( $class, $text ) = @_;
+    my $twig = XML::Twig->new;
+    $twig->parse($text);
+    my $root = $twig->root;
+    bless $root, __PACKAGE__;
+    Bio::Phylo::NeXML::DOM::Element::_recurse_bless($root);
+    return $root;
+}
+
 =back
 
 =head2 Tagname mutators/accessors
